@@ -1,14 +1,20 @@
-# -*- coding: utf-8 -*-
-from pkg_resources import get_distribution, DistributionNotFound
+import sys
+
+if sys.version_info[:2] >= (3, 8):
+    # TODO: Import directly (no need for conditional) when `python_requires = >= 3.8`
+    from importlib.metadata import PackageNotFoundError, version  # pragma: no cover
+else:
+    from importlib_metadata import PackageNotFoundError, version  # pragma: no cover
 
 try:
     # Change here if project is renamed and does not equal the package name
     dist_name = __name__
-    __version__ = get_distribution(dist_name).version
-except DistributionNotFound:
-    __version__ = 'unknown'
+    __version__ = version(dist_name)
+except PackageNotFoundError:  # pragma: no cover
+    __version__ = "unknown"
 finally:
-    del get_distribution, DistributionNotFound
+    del version, PackageNotFoundError
+
 
 from .io import read_data  # noqa: E402
 from .preprocess import preprocess, filter_dataframe, replace_parts_animal_movement, resample_systematic, \
@@ -21,4 +27,4 @@ from .clustering import dtw_matrix, ts_cluster, get_heading_difference, compute_
 # noqa: E402
 from .plot import plot_animal, plot_pace, plot_movement  # noqa: E402
 
-from .network import network_time_graphlist
+from .network import network_time_graphlist
\ No newline at end of file
